@@ -1,3 +1,3 @@
 from .custom_exceptions import InvalidParameterException, InvalidFileTypeException
 from .tableau_server_exceptions import InvalidRestApiVersion, InvalidTableauServerQuery, ContentOverwriteDisabled, \
-    ContentNotFound, UsersNotFound
+    ContentNotFound, PaginationError, UsersNotFound
